@@ -1,12 +1,7 @@
 use ratatui::layout::Rect;
 
-#[derive(Default)]
+#[derive(Clone, Copy, Default)]
 pub struct Layout {
-	pub header: Rect,
-
-	pub parent:  Rect,
 	pub current: Rect,
 	pub preview: Rect,
-
-	pub status: Rect,
 }
