@@ -1,8 +1,9 @@
+use std::str::FromStr;
+
 use serde::{Deserialize, Serialize};
 use validator::Validate;
 
-use super::{ManagerRatio, SortBy};
-use crate::{validation::check_validation, MERGED_YAZI};
+use super::{ManagerRatio, MouseEvents, SortBy};
 
 #[derive(Debug, Deserialize, Serialize, Validate)]
 pub struct Manager {
@@ -13,24 +14,29 @@ pub struct Manager {
 	pub sort_sensitive: bool,
 	pub sort_reverse:   bool,
 	pub sort_dir_first: bool,
+	pub sort_translit:  bool,
 
 	// Display
 	#[validate(length(min = 1, max = 20, message = "must be between 1 and 20 characters"))]
 	pub linemode:     String,
 	pub show_hidden:  bool,
 	pub show_symlink: bool,
+	pub scrolloff:    u8,
+	pub mouse_events: MouseEvents,
 }
 
-impl Default for Manager {
-	fn default() -> Self {
+impl FromStr for Manager {
+	type Err = anyhow::Error;
+
+	fn from_str(s: &str) -> Result<Self, Self::Err> {
 		#[derive(Deserialize)]
 		struct Outer {
 			manager: Manager,
 		}
 
-		let manager = toml::from_str::<Outer>(&MERGED_YAZI).unwrap().manager;
+		let manager = toml::from_str::<Outer>(s)?.manager;
+		manager.validate()?;
 
-		check_validation(manager.validate());
-		manager
+		Ok(manager)
 	}
 }
