@@ -1,9 +1,15 @@
-use std::path::MAIN_SEPARATOR;
+use std::path::MAIN_SEPARATOR_STR;
 
-use yazi_shared::{event::Cmd, render};
+use yazi_shared::{event::{Cmd, Data}, render};
 
 use crate::input::Input;
 
+#[cfg(windows)]
+const SEPARATOR: [char; 2] = ['/', '\\'];
+
+#[cfg(not(windows))]
+const SEPARATOR: char = std::path::MAIN_SEPARATOR;
+
 pub struct Opt {
 	word:   String,
 	ticket: usize,
@@ -12,8 +18,8 @@ pub struct Opt {
 impl From<Cmd> for Opt {
 	fn from(mut c: Cmd) -> Self {
 		Self {
-			word:   c.take_first().unwrap_or_default(),
-			ticket: c.take_name("ticket").and_then(|s| s.parse().ok()).unwrap_or(0),
+			word:   c.take_first_str().unwrap_or_default(),
+			ticket: c.get("ticket").and_then(Data::as_usize).unwrap_or(0),
 		}
 	}
 }
@@ -26,10 +32,10 @@ impl Input {
 		}
 
 		let [before, after] = self.partition();
-		let new = if let Some((prefix, _)) = before.rsplit_once(MAIN_SEPARATOR) {
-			format!("{prefix}/{}{after}", opt.word)
+		let new = if let Some((prefix, _)) = before.rsplit_once(SEPARATOR) {
+			format!("{prefix}/{}{after}", opt.word).replace(SEPARATOR, MAIN_SEPARATOR_STR)
 		} else {
-			format!("{}{after}", opt.word)
+			format!("{}{after}", opt.word).replace(SEPARATOR, MAIN_SEPARATOR_STR)
 		};
 
 		let snap = self.snaps.current_mut();
