@@ -6,20 +6,17 @@
 	clippy::unit_arg
 )]
 
-mod clipboard;
 pub mod completion;
-pub mod folder;
 pub mod help;
 pub mod input;
 pub mod manager;
 pub mod notify;
 pub mod select;
-mod step;
 pub mod tab;
 pub mod tasks;
 pub mod which;
 
-pub use clipboard::*;
-pub use step::*;
-
-pub fn init() { CLIPBOARD.with(Default::default); }
+pub fn init() {
+	manager::WATCHED.with(<_>::default);
+	manager::LINKED.with(<_>::default);
+}
