@@ -8,9 +8,7 @@ pub struct Opt {
 }
 
 impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self {
-		Self { force: c.named.contains_key("force"), follow: c.named.contains_key("follow") }
-	}
+	fn from(c: Cmd) -> Self { Self { force: c.bool("force"), follow: c.bool("follow") } }
 }
 
 impl Manager {
