@@ -1,4 +1,4 @@
-use std::env;
+use std::{env, path::MAIN_SEPARATOR};
 
 use crossterm::{execute, terminal::SetTitle};
 use yazi_shared::event::Cmd;
@@ -7,13 +7,9 @@ use crate::{manager::Manager, tasks::Tasks};
 
 impl Manager {
 	fn title(&self) -> String {
-		#[cfg(unix)]
-		let home = env::var_os("HOME").unwrap_or_default();
-		#[cfg(windows)]
-		let home = env::var_os("USERPROFILE").unwrap_or_default();
-
+		let home = dirs::home_dir().unwrap_or_default();
 		if let Some(p) = self.cwd().strip_prefix(home) {
-			format!("Yazi: ~/{}", p.display())
+			format!("Yazi: ~{}{}", MAIN_SEPARATOR, p.display())
 		} else {
 			format!("Yazi: {}", self.cwd().display())
 		}
@@ -35,6 +31,6 @@ impl Manager {
 		self.hover(None);
 		self.update_paged((), tasks);
 
-		tasks.preload_sorted(&self.current().files);
+		tasks.prework_sorted(&self.current().files);
 	}
 }
