@@ -7,15 +7,17 @@ use crate::{manager::Manager, tasks::Tasks};
 pub struct Opt {
 	force:       bool,
 	permanently: bool,
+	hovered:     bool,
 	targets:     Vec<Url>,
 }
 
 impl From<Cmd> for Opt {
 	fn from(mut c: Cmd) -> Self {
 		Self {
-			force:       c.named.contains_key("force"),
-			permanently: c.named.contains_key("permanently"),
-			targets:     c.take_data().unwrap_or_default(),
+			force:       c.bool("force"),
+			permanently: c.bool("permanently"),
+			hovered:     c.bool("hovered"),
+			targets:     c.take_any("targets").unwrap_or_default(),
 		}
 	}
 }
@@ -25,9 +27,16 @@ impl Manager {
 		if !self.active_mut().try_escape_visual() {
 			return;
 		}
+		let Some(hovered) = self.hovered().map(|h| &h.url) else {
+			return;
+		};
 
 		let mut opt = opt.into() as Opt;
-		opt.targets = self.selected_or_hovered().into_iter().cloned().collect();
+		opt.targets = if opt.hovered {
+			vec![hovered.clone()]
+		} else {
+			self.selected_or_hovered(false).cloned().collect()
+		};
 
 		if opt.force {
 			return self.remove_do(opt, tasks);
@@ -61,6 +70,7 @@ impl Manager {
 			self.yanked.remove(u);
 		}
 
+		self.yanked.catchup_revision(false);
 		tasks.file_remove(opt.targets, opt.permanently);
 	}
 }
