@@ -1,32 +1,31 @@
 use std::collections::HashMap;
 
-use yazi_plugin::ValueSendable;
+use tracing::error;
 use yazi_shared::{event::Cmd, fs::Url, render};
 
-use crate::{manager::Manager, tasks::Tasks};
+use crate::{manager::{Manager, LINKED}, tasks::Tasks};
 
 pub struct Opt {
-	data: ValueSendable,
+	updates: HashMap<String, String>,
 }
 
 impl TryFrom<Cmd> for Opt {
 	type Error = ();
 
 	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> {
-		Ok(Self { data: c.take_data().ok_or(())? })
+		Ok(Self { updates: c.take("updates").ok_or(())?.into_dict_string() })
 	}
 }
 
 impl Manager {
 	pub fn update_mimetype(&mut self, opt: impl TryInto<Opt>, tasks: &Tasks) {
 		let Ok(opt) = opt.try_into() else {
-			return;
+			return error!("invalid arguments for update_mimetype");
 		};
 
-		let linked = self.watcher.linked.read();
+		let linked = LINKED.read();
 		let updates = opt
-			.data
-			.into_table_string()
+			.updates
 			.into_iter()
 			.map(|(url, mime)| (Url::from(url), mime))
 			.filter(|(url, mime)| self.mimetype.get(url) != Some(mime))
@@ -54,7 +53,7 @@ impl Manager {
 		self.mimetype.extend(updates);
 		self.peek(false);
 
-		tasks.preload_affected(&affected, &self.mimetype);
+		tasks.prework_affected(&affected, &self.mimetype);
 		render!();
 	}
 }
