@@ -3,8 +3,10 @@ mod linked;
 mod manager;
 mod tabs;
 mod watcher;
+mod yanked;
 
 pub use linked::*;
 pub use manager::*;
 pub use tabs::*;
 pub use watcher::*;
+pub use yanked::*;
