@@ -1,23 +1,24 @@
 use std::{collections::{HashMap, HashSet}, time::{Duration, SystemTime}};
 
 use anyhow::Result;
-use notify::{event::{MetadataKind, ModifyKind}, EventKind, RecommendedWatcher, RecursiveMode, Watcher as _Watcher};
+use notify::{RecommendedWatcher, RecursiveMode, Watcher as _Watcher};
 use parking_lot::RwLock;
 use tokio::{fs, pin, sync::{mpsc::{self, UnboundedReceiver}, watch}};
 use tokio_stream::{wrappers::UnboundedReceiverStream, StreamExt};
 use tracing::error;
+use yazi_fs::{Files, Folder};
 use yazi_plugin::isolate;
 use yazi_proxy::WATCHER;
-use yazi_shared::{fs::{File, FilesOp, Url}, RoCell};
+use yazi_shared::{fs::{symlink_realname, File, FilesOp, Url}, RoCell};
 
 use super::Linked;
-use crate::folder::{Files, Folder};
 
 pub(crate) static WATCHED: RoCell<RwLock<HashSet<Url>>> = RoCell::new();
 pub static LINKED: RoCell<RwLock<Linked>> = RoCell::new();
 
 pub struct Watcher {
-	tx: watch::Sender<HashSet<Url>>,
+	in_tx:  watch::Sender<HashSet<Url>>,
+	out_tx: mpsc::UnboundedSender<Url>,
 }
 
 impl Watcher {
@@ -25,42 +26,34 @@ impl Watcher {
 		let (in_tx, in_rx) = watch::channel(Default::default());
 		let (out_tx, out_rx) = mpsc::unbounded_channel();
 
+		let out_tx_ = out_tx.clone();
 		let watcher = RecommendedWatcher::new(
 			move |res: Result<notify::Event, notify::Error>| {
 				let Ok(event) = res else { return };
-
-				match event.kind {
-					EventKind::Create(_) => {}
-					EventKind::Modify(kind) => match kind {
-						ModifyKind::Data(_) => {}
-						ModifyKind::Metadata(md) => match md {
-							MetadataKind::WriteTime => {}
-							MetadataKind::Permissions => {}
-							MetadataKind::Ownership => {}
-							_ => return,
-						},
-						ModifyKind::Name(_) => {}
-						_ => return,
-					},
-					EventKind::Remove(_) => {}
-					_ => return,
+				if event.kind.is_access() {
+					return;
 				}
-
 				for path in event.paths {
-					out_tx.send(Url::from(path)).ok();
+					out_tx_.send(Url::from(path)).ok();
 				}
 			},
 			Default::default(),
 		);
 
-		tokio::spawn(Self::on_in(in_rx, watcher.unwrap()));
-		tokio::spawn(Self::on_out(out_rx));
-		Self { tx: in_tx }
+		tokio::spawn(Self::fan_in(in_rx, watcher.unwrap()));
+		tokio::spawn(Self::fan_out(out_rx));
+		Self { in_tx, out_tx }
 	}
 
 	pub(super) fn watch(&mut self, mut new: HashSet<&Url>) {
 		new.retain(|&u| u.is_regular());
-		self.tx.send(new.into_iter().cloned().collect()).ok();
+		self.in_tx.send(new.into_iter().cloned().collect()).ok();
+	}
+
+	pub(super) fn push_file(&self, url: Url) {
+		if url.parent_url().is_some_and(|p| WATCHED.read().contains(&p)) {
+			self.out_tx.send(url).ok();
+		}
 	}
 
 	pub(super) fn trigger_dirs(&self, folders: &[&Folder]) {
@@ -83,14 +76,21 @@ impl Watcher {
 		});
 	}
 
-	async fn on_in(mut rx: watch::Receiver<HashSet<Url>>, mut watcher: RecommendedWatcher) {
+	async fn fan_in(mut rx: watch::Receiver<HashSet<Url>>, mut watcher: RecommendedWatcher) {
 		loop {
 			let (mut to_unwatch, mut to_watch): (HashSet<_>, HashSet<_>) = {
 				let (new, old) = (&*rx.borrow_and_update(), &*WATCHED.read());
 				(old.difference(new).cloned().collect(), new.difference(old).cloned().collect())
 			};
 
-			to_unwatch.retain(|u| watcher.unwatch(u).is_ok());
+			to_unwatch.retain(|u| match watcher.unwatch(u) {
+				Ok(_) => true,
+				Err(e) if matches!(e.kind, notify::ErrorKind::WatchNotFound) => true,
+				Err(e) => {
+					error!("Unwatch failed: {e:?}");
+					false
+				}
+			});
 			to_watch.retain(|u| watcher.watch(u, RecursiveMode::NonRecursive).is_ok());
 
 			{
@@ -109,34 +109,46 @@ impl Watcher {
 		}
 	}
 
-	async fn on_out(rx: UnboundedReceiver<Url>) {
+	async fn fan_out(rx: UnboundedReceiver<Url>) {
 		// TODO: revert this once a new notification is implemented
 		let rx = UnboundedReceiverStream::new(rx).chunks_timeout(1000, Duration::from_millis(50));
 		pin!(rx);
 
-		while let Some(urls) = rx.next().await {
+		while let Some(chunk) = rx.next().await {
+			let urls: HashSet<_> = chunk.into_iter().collect();
+			let mut cached: HashMap<_, _> = HashMap::new();
+
 			let _permit = WATCHER.acquire().await.unwrap();
 			let mut reload = Vec::with_capacity(urls.len());
 
-			for u in urls.into_iter().collect::<HashSet<_>>() {
-				let Some(parent) = u.parent_url() else { continue };
+			for url in urls {
+				let Some(name) = url.file_name() else { continue };
+				let Some(parent) = url.parent_url() else { continue };
 
-				let Ok(file) = File::from(u.clone()).await else {
-					FilesOp::Deleting(parent, vec![u]).emit();
+				let Ok(file) = File::from(url.clone()).await else {
+					FilesOp::Deleting(parent, vec![url]).emit();
 					continue;
 				};
 
+				let eq = (!file.is_link() && fs::canonicalize(&url).await.is_ok_and(|p| p == *url))
+					|| symlink_realname(&url, &mut cached).await.is_ok_and(|s| s == name);
+
+				if !eq {
+					FilesOp::Deleting(parent, vec![url]).emit();
+					continue;
+				}
+
 				if !file.is_dir() {
 					reload.push(file.clone());
 				}
-				FilesOp::Upserting(parent, HashMap::from_iter([(u, file)])).emit();
+				FilesOp::Upserting(parent, HashMap::from_iter([(url, file)])).emit();
 			}
 
 			if reload.is_empty() {
 				continue;
 			}
-			if let Err(e) = isolate::preload("mime", reload, true).await {
-				error!("preload in watcher failed: {e}");
+			if let Err(e) = isolate::fetch("mime", reload).await {
+				error!("Fetch `mime` failed in watcher: {e}");
 			}
 		}
 	}
