@@ -1,4 +1,4 @@
-use yazi_shared::{event::Cmd, render};
+use yazi_shared::{event::{Cmd, Data}, render};
 
 use crate::select::Select;
 
@@ -7,9 +7,7 @@ pub struct Opt {
 }
 
 impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
-		Self { step: c.take_first().and_then(|s| s.parse().ok()).unwrap_or(0) }
-	}
+	fn from(c: Cmd) -> Self { Self { step: c.first().and_then(Data::as_isize).unwrap_or(0) } }
 }
 
 impl Select {
