@@ -1,7 +1,8 @@
+use yazi_fs::Step;
 use yazi_proxy::ManagerProxy;
-use yazi_shared::{event::Cmd, render};
+use yazi_shared::{event::{Cmd, Data}, render};
 
-use crate::{tab::Tab, Step};
+use crate::tab::Tab;
 
 pub struct Opt {
 	step: Step,
@@ -9,15 +10,18 @@ pub struct Opt {
 
 impl From<Cmd> for Opt {
 	fn from(mut c: Cmd) -> Self {
-		Self { step: c.take_first().and_then(|s| s.parse().ok()).unwrap_or_default() }
+		let step = match c.take_first() {
+			Some(Data::Integer(i)) => Step::from(i as isize),
+			Some(Data::String(s)) => s.parse().unwrap_or_default(),
+			_ => Step::default(),
+		};
+
+		Self { step }
 	}
 }
 
-impl<T> From<T> for Opt
-where
-	T: Into<Step>,
-{
-	fn from(t: T) -> Self { Self { step: t.into() } }
+impl From<isize> for Opt {
+	fn from(n: isize) -> Self { Self { step: n.into() } }
 }
 
 impl Tab {
