@@ -1,15 +1,16 @@
 use std::ffi::{OsStr, OsString};
 
+use yazi_plugin::CLIPBOARD;
 use yazi_shared::event::Cmd;
 
-use crate::{tab::Tab, CLIPBOARD};
+use crate::tab::Tab;
 
 pub struct Opt {
 	type_: String,
 }
 
 impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self { Self { type_: c.take_first().unwrap_or_default() } }
+	fn from(mut c: Cmd) -> Self { Self { type_: c.take_first_str().unwrap_or_default() } }
 }
 
 impl Tab {
@@ -20,7 +21,7 @@ impl Tab {
 		}
 
 		let mut s = OsString::new();
-		let mut it = self.selected_or_hovered().into_iter().peekable();
+		let mut it = self.selected_or_hovered(true).peekable();
 		while let Some(u) = it.next() {
 			s.push(match opt.type_.as_str() {
 				"path" => u.as_os_str(),
