@@ -8,22 +8,24 @@ bitflags! {
 	pub struct Opt: u8 {
 		const FIND   = 0b00001;
 		const VISUAL = 0b00010;
-		const SELECT = 0b00100;
-		const FILTER = 0b01000;
+		const FILTER = 0b00100;
+		const SELECT = 0b01000;
 		const SEARCH = 0b10000;
 	}
 }
 
 impl From<Cmd> for Opt {
 	fn from(c: Cmd) -> Self {
-		c.named.iter().fold(Opt::empty(), |acc, (k, _)| match k.as_str() {
-			"all" => Self::all(),
-			"find" => acc | Self::FIND,
-			"visual" => acc | Self::VISUAL,
-			"select" => acc | Self::SELECT,
-			"filter" => acc | Self::FILTER,
-			"search" => acc | Self::SEARCH,
-			_ => acc,
+		c.args.iter().fold(Opt::empty(), |acc, (k, v)| {
+			match (k.as_str(), v.as_bool().unwrap_or(false)) {
+				("all", true) => Self::all(),
+				("find", true) => acc | Self::FIND,
+				("visual", true) => acc | Self::VISUAL,
+				("filter", true) => acc | Self::FILTER,
+				("select", true) => acc | Self::SELECT,
+				("search", true) => acc | Self::SEARCH,
+				_ => acc,
+			}
 		})
 	}
 }
@@ -34,8 +36,8 @@ impl Tab {
 		if opt.is_empty() {
 			_ = self.escape_find()
 				|| self.escape_visual()
-				|| self.escape_select()
 				|| self.escape_filter()
+				|| self.escape_select()
 				|| self.escape_search();
 			return;
 		}
@@ -46,12 +48,12 @@ impl Tab {
 		if opt.contains(Opt::VISUAL) {
 			self.escape_visual();
 		}
-		if opt.contains(Opt::SELECT) {
-			self.escape_select();
-		}
 		if opt.contains(Opt::FILTER) {
 			self.escape_filter();
 		}
+		if opt.contains(Opt::SELECT) {
+			self.escape_select();
+		}
 		if opt.contains(Opt::SEARCH) {
 			self.escape_search();
 		}
@@ -68,6 +70,15 @@ impl Tab {
 		true
 	}
 
+	pub fn escape_filter(&mut self) -> bool {
+		if self.current.files.filter().is_none() {
+			return false;
+		}
+
+		self.filter_do(super::filter::Opt::default());
+		render_and!(true)
+	}
+
 	pub fn escape_select(&mut self) -> bool {
 		if self.selected.is_empty() {
 			return false;
@@ -80,15 +91,6 @@ impl Tab {
 		render_and!(true)
 	}
 
-	pub fn escape_filter(&mut self) -> bool {
-		if self.current.files.filter().is_none() {
-			return false;
-		}
-
-		self.filter_do(super::filter::Opt::default());
-		render_and!(true)
-	}
-
 	pub fn escape_search(&mut self) -> bool {
 		if !self.current.cwd.is_search() {
 			return false;
