@@ -3,10 +3,11 @@ use std::time::Duration;
 use tokio::pin;
 use tokio_stream::{wrappers::UnboundedReceiverStream, StreamExt};
 use yazi_config::popup::InputCfg;
+use yazi_fs::{Filter, FilterCase};
 use yazi_proxy::{InputProxy, ManagerProxy};
 use yazi_shared::{emit, event::Cmd, render, Debounce, InputError, Layer};
 
-use crate::{folder::{Filter, FilterCase}, tab::Tab};
+use crate::tab::Tab;
 
 #[derive(Default)]
 pub struct Opt {
@@ -18,9 +19,9 @@ pub struct Opt {
 impl From<Cmd> for Opt {
 	fn from(mut c: Cmd) -> Self {
 		Self {
-			query: c.take_first().unwrap_or_default(),
+			query: c.take_first_str().unwrap_or_default(),
 			case:  FilterCase::from(&c),
-			done:  c.named.contains_key("done"),
+			done:  c.bool("done"),
 		}
 	}
 }
@@ -69,9 +70,11 @@ impl Tab {
 			return;
 		}
 
-		if self.current.repos(hovered) {
+		self.current.repos(hovered.as_ref());
+		if self.current.hovered().map(|f| &f.url) != hovered.as_ref() {
 			ManagerProxy::hover(None);
 		}
+
 		render!();
 	}
 }
