@@ -3,10 +3,11 @@ use std::time::Duration;
 use tokio::pin;
 use tokio_stream::{wrappers::UnboundedReceiverStream, StreamExt};
 use yazi_config::popup::InputCfg;
+use yazi_fs::FilterCase;
 use yazi_proxy::InputProxy;
 use yazi_shared::{emit, event::Cmd, render, Debounce, InputError, Layer};
 
-use crate::{folder::FilterCase, tab::{Finder, Tab}};
+use crate::tab::{Finder, Tab};
 
 pub struct Opt {
 	query: Option<String>,
@@ -16,11 +17,7 @@ pub struct Opt {
 
 impl From<Cmd> for Opt {
 	fn from(mut c: Cmd) -> Self {
-		Self {
-			query: c.take_first(),
-			prev:  c.named.contains_key("previous"),
-			case:  FilterCase::from(&c),
-		}
+		Self { query: c.take_first_str(), prev: c.bool("previous"), case: FilterCase::from(&c) }
 	}
 }
 
@@ -29,7 +26,7 @@ pub struct ArrowOpt {
 }
 
 impl From<Cmd> for ArrowOpt {
-	fn from(c: Cmd) -> Self { Self { prev: c.named.contains_key("previous") } }
+	fn from(c: Cmd) -> Self { Self { prev: c.bool("previous") } }
 }
 
 impl Tab {
