@@ -3,13 +3,12 @@ use std::time::{Duration, SystemTime};
 use tokio::{pin, task::JoinHandle};
 use tokio_stream::{wrappers::UnboundedReceiverStream, StreamExt};
 use tokio_util::sync::CancellationToken;
-use yazi_adaptor::ADAPTOR;
+use yazi_adapter::ADAPTOR;
 use yazi_config::PLUGIN;
+use yazi_fs::Files;
 use yazi_plugin::{external::Highlighter, isolate, utils::PreviewLock};
 use yazi_shared::{fs::{Cha, File, FilesOp, Url}, MIME_DIR};
 
-use crate::folder::Files;
-
 #[derive(Default)]
 pub struct Preview {
 	pub lock: Option<PreviewLock>,
@@ -32,9 +31,9 @@ impl Preview {
 
 		self.abort();
 		if previewer.sync {
-			isolate::peek_sync(&previewer.cmd, file, self.skip);
+			isolate::peek_sync(&previewer.run, file, self.skip);
 		} else {
-			self.previewer_ct = Some(isolate::peek(&previewer.cmd, file, self.skip));
+			self.previewer_ct = Some(isolate::peek(&previewer.run, file, self.skip));
 		}
 	}
 
@@ -46,10 +45,6 @@ impl Preview {
 		let url = file.url();
 		self.go(file, MIME_DIR, force);
 
-		if matches!(&self.folder_loader, Some((u, _)) if *u == url) {
-			return;
-		}
-
 		self.folder_loader.take().map(|(_, h)| h.abort());
 		self.folder_loader = Some((
 			url.clone(),
@@ -102,12 +97,12 @@ impl Preview {
 		*url == lock.url
 			&& self.skip == lock.skip
 			&& cha.len == lock.cha.len
-			&& cha.modified == lock.cha.modified
+			&& cha.mtime == lock.cha.mtime
 			&& cha.kind == lock.cha.kind
 			&& {
 				#[cfg(unix)]
 				{
-					cha.permissions == lock.cha.permissions
+					cha.perm == lock.cha.perm
 				}
 				#[cfg(windows)]
 				{
