@@ -1,13 +1,16 @@
-use std::collections::HashMap;
+use std::{collections::HashMap, iter};
 
 use anyhow::Result;
 use tokio::task::JoinHandle;
+use yazi_fs::{Folder, FolderStage};
 use yazi_shared::{fs::Url, render};
 
 use super::{Backstack, Config, Finder, Mode, Preview};
-use crate::{folder::{Folder, FolderStage}, tab::Selected};
+use crate::tab::Selected;
 
+#[derive(Default)]
 pub struct Tab {
+	pub idx:     usize,
 	pub mode:    Mode,
 	pub conf:    Config,
 	pub current: Folder,
@@ -22,51 +25,39 @@ pub struct Tab {
 	pub(super) search: Option<JoinHandle<Result<()>>>,
 }
 
-impl From<Url> for Tab {
-	fn from(url: Url) -> Self {
-		let parent = url.parent_url().map(Folder::from);
-
-		Self {
-			mode: Default::default(),
-			current: Folder::from(url.clone()),
-			parent,
-
-			backstack: Backstack::new(url),
-			history: Default::default(),
-			selected: Default::default(),
-
-			preview: Default::default(),
-			finder: None,
-			search: None,
-
-			conf: Default::default(),
+impl Tab {
+	pub fn shutdown(&mut self) {
+		if let Some(handle) = self.search.take() {
+			handle.abort();
 		}
 	}
 }
 
-impl From<&Url> for Tab {
-	fn from(url: &Url) -> Self { Self::from(url.clone()) }
-}
-
 impl Tab {
 	// --- Current
-	pub fn selected_or_hovered(&self) -> Vec<&Url> {
+	pub fn selected_or_hovered(&self, reorder: bool) -> Box<dyn Iterator<Item = &Url> + '_> {
 		if self.selected.is_empty() {
-			self.current.hovered().map(|h| vec![&h.url]).unwrap_or_default()
+			Box::new(self.current.hovered().map(|h| vec![&h.url]).unwrap_or_default().into_iter())
+		} else if !reorder {
+			Box::new(self.selected.keys())
 		} else {
-			self.selected.iter().collect()
+			let mut vec: Vec<_> = self.selected.iter().collect();
+			vec.sort_unstable_by(|a, b| a.1.cmp(b.1));
+			Box::new(vec.into_iter().map(|(k, _)| k))
 		}
 	}
 
-	pub fn hovered_and_selected(&self) -> Vec<&Url> {
-		let Some(h) = self.current.hovered() else {
-			return vec![];
-		};
+	pub fn hovered_and_selected(&self, reorder: bool) -> Box<dyn Iterator<Item = &Url> + '_> {
+		let Some(h) = self.current.hovered() else { return Box::new(iter::empty()) };
 
 		if self.selected.is_empty() {
-			vec![&h.url, &h.url]
+			Box::new([&h.url, &h.url].into_iter())
+		} else if !reorder {
+			Box::new([&h.url].into_iter().chain(self.selected.keys()))
 		} else {
-			[&h.url].into_iter().chain(self.selected.iter()).collect()
+			let mut vec: Vec<_> = self.selected.iter().collect();
+			vec.sort_unstable_by(|a, b| a.1.cmp(b.1));
+			Box::new([&h.url].into_iter().chain(vec.into_iter().map(|(k, _)| k)))
 		}
 	}
 
