@@ -4,7 +4,7 @@ use crate::tasks::Tasks;
 
 impl Tasks {
 	pub fn cancel(&mut self, _: Cmd) {
-		let id = self.scheduler.ongoing.lock().get_id(self.cursor);
+		let id = self.ongoing().lock().get_id(self.cursor);
 		if id.map(|id| self.scheduler.cancel(id)) != Some(true) {
 			return;
 		}
