@@ -1,5 +1,6 @@
 mod arrow;
 mod cancel;
 mod inspect;
-mod open;
+mod open_with;
+mod process_exec;
 mod toggle;
