@@ -1,5 +1,5 @@
 use yazi_config::keymap::{ControlCow, Key};
-use yazi_shared::{emit, render, Layer};
+use yazi_shared::{emit, render, render_and, Layer};
 
 #[derive(Default)]
 pub struct Which {
@@ -7,19 +7,12 @@ pub struct Which {
 	pub times:        usize,
 	pub cands:        Vec<ControlCow>,
 
+	// Visibility
 	pub visible: bool,
 	pub silent:  bool,
 }
 
 impl Which {
-	fn reset(&mut self) {
-		self.times = 0;
-		self.cands.clear();
-
-		self.visible = false;
-		self.silent = false;
-	}
-
 	pub fn type_(&mut self, key: Key) -> bool {
 		self.cands.retain(|c| c.on.len() > self.times && c.on[self.times] == key);
 		self.times += 1;
@@ -34,7 +27,14 @@ impl Which {
 			self.reset();
 		}
 
-		render!();
-		true
+		render_and!(true)
+	}
+
+	fn reset(&mut self) {
+		self.times = 0;
+		self.cands.clear();
+
+		self.visible = false;
+		self.silent = false;
 	}
 }
