@@ -15,7 +15,8 @@ impl Logs {
 		let (handle, guard) = tracing_appender::non_blocking(appender);
 
 		// let filter = EnvFilter::from_default_env();
-		let subscriber = Registry::default().with(fmt::layer().pretty().with_writer(handle));
+		let subscriber = Registry::default()
+			.with(fmt::layer().pretty().with_writer(handle).with_ansi(cfg!(debug_assertions)));
 
 		tracing::subscriber::set_global_default(subscriber).expect("setting default subscriber failed");
 
