@@ -11,6 +11,7 @@ mod line;
 mod list;
 mod padding;
 mod paragraph;
+mod position;
 mod rect;
 mod span;
 mod style;
@@ -26,6 +27,7 @@ pub use line::*;
 pub use list::*;
 pub use padding::*;
 pub use paragraph::*;
+pub use position::*;
 pub use rect::*;
 pub use span::*;
 pub use style::*;
