@@ -8,21 +8,21 @@ pub struct RgOpt {
 	pub cwd:     Url,
 	pub hidden:  bool,
 	pub subject: String,
+	pub args:    Vec<String>,
 }
 
 pub fn rg(opt: RgOpt) -> Result<UnboundedReceiver<File>> {
 	let mut child = Command::new("rg")
 		.current_dir(&opt.cwd)
 		.args(["--color=never", "--files-with-matches", "--smart-case"])
-		.args(if opt.hidden { ["--hidden", "--no-ignore"] } else { ["--no-hidden", "--ignore"] })
-		.arg(&opt.subject)
+		.arg(if opt.hidden { "--hidden" } else { "--no-hidden" })
+		.args(opt.args)
+		.arg(opt.subject)
 		.kill_on_drop(true)
 		.stdout(Stdio::piped())
-		.stderr(Stdio::piped())
+		.stderr(Stdio::null())
 		.spawn()?;
 
-	drop(child.stderr.take());
-
 	let mut it = BufReader::new(child.stdout.take().unwrap()).lines();
 	let (tx, rx) = mpsc::unbounded_channel();
 
