@@ -1,12 +1,10 @@
 #[cfg(unix)]
-pub(super) static USERS_CACHE: yazi_shared::RoCell<uzers::UsersCache> = yazi_shared::RoCell::new();
-
 pub(super) static HOSTNAME_CACHE: std::sync::OnceLock<Option<String>> = std::sync::OnceLock::new();
 
 pub(super) struct Utils;
 
-pub fn install(lua: &mlua::Lua) -> mlua::Result<()> {
-	let ya: mlua::Table = lua.create_table()?;
+pub fn install(lua: &'static mlua::Lua) -> mlua::Result<()> {
+	let ya = lua.create_table()?;
 
 	Utils::app(lua, &ya)?;
 	Utils::cache(lua, &ya)?;
@@ -14,8 +12,8 @@ pub fn install(lua: &mlua::Lua) -> mlua::Result<()> {
 	Utils::image(lua, &ya)?;
 	Utils::layer(lua, &ya)?;
 	Utils::log(lua, &ya)?;
-	Utils::plugin(lua, &ya)?;
 	Utils::preview(lua, &ya)?;
+	Utils::sync(lua, &ya)?;
 	Utils::target(lua, &ya)?;
 	Utils::text(lua, &ya)?;
 	Utils::time(lua, &ya)?;
@@ -24,7 +22,21 @@ pub fn install(lua: &mlua::Lua) -> mlua::Result<()> {
 	lua.globals().raw_set("ya", ya)
 }
 
-pub fn init() {
-	#[cfg(unix)]
-	USERS_CACHE.with(Default::default);
+pub fn install_isolate(lua: &mlua::Lua) -> mlua::Result<()> {
+	let ya = lua.create_table()?;
+
+	Utils::app(lua, &ya)?;
+	Utils::cache(lua, &ya)?;
+	Utils::call(lua, &ya)?;
+	Utils::image(lua, &ya)?;
+	Utils::layer(lua, &ya)?;
+	Utils::log(lua, &ya)?;
+	Utils::preview(lua, &ya)?;
+	Utils::sync_isolate(lua, &ya)?;
+	Utils::target(lua, &ya)?;
+	Utils::text(lua, &ya)?;
+	Utils::time(lua, &ya)?;
+	Utils::user(lua, &ya)?;
+
+	lua.globals().raw_set("ya", ya)
 }
