@@ -1,3 +1,5 @@
+use std::borrow::Cow;
+
 use yazi_config::open::Opener;
 use yazi_shared::{event::Cmd, fs::Url};
 
@@ -10,17 +12,17 @@ pub struct OpenDoOpt {
 }
 
 impl From<Cmd> for OpenDoOpt {
-	fn from(mut c: Cmd) -> Self { c.take_data().unwrap_or_default() }
+	fn from(mut c: Cmd) -> Self { c.take_any("option").unwrap_or_default() }
 }
 
 // --- Open with
 pub struct OpenWithOpt {
 	pub targets: Vec<Url>,
-	pub opener:  Opener,
+	pub opener:  Cow<'static, Opener>,
 }
 
 impl TryFrom<Cmd> for OpenWithOpt {
 	type Error = ();
 
-	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> { c.take_data().ok_or(()) }
+	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> { c.take_any("option").ok_or(()) }
 }
