@@ -18,3 +18,13 @@ impl CharKind {
 		}
 	}
 }
+
+pub fn strip_trailing_newline(mut s: String) -> String {
+	if s.ends_with('\n') {
+		s.pop();
+	}
+	if s.ends_with('\r') {
+		s.pop();
+	}
+	s
+}
