@@ -1,4 +1,4 @@
-use std::{cell::Cell, ffi::OsStr, fs::Metadata, ops::Deref};
+use std::{cell::Cell, ffi::OsStr, fs::{FileType, Metadata}, ops::Deref};
 
 use anyhow::Result;
 use tokio::fs;
@@ -7,8 +7,8 @@ use crate::{fs::{Cha, ChaKind, Url}, theme::IconCache};
 
 #[derive(Clone, Debug, Default)]
 pub struct File {
-	pub url:     Url,
 	pub cha:     Cha,
+	pub url:     Url,
 	pub link_to: Option<Url>,
 	pub icon:    Cell<IconCache>,
 }
@@ -20,6 +20,18 @@ impl Deref for File {
 	fn deref(&self) -> &Self::Target { &self.cha }
 }
 
+impl AsRef<File> for File {
+	#[inline]
+	fn as_ref(&self) -> &File { self }
+}
+
+impl PartialEq for File {
+	#[inline]
+	fn eq(&self, other: &Self) -> bool {
+		self.cha == other.cha && self.url == other.url && self.link_to == other.link_to
+	}
+}
+
 impl File {
 	#[inline]
 	pub async fn from(url: Url) -> Result<Self> {
@@ -54,11 +66,13 @@ impl File {
 			}
 		}
 
-		Self { url, cha: Cha::from(meta).with_kind(ck), link_to, icon: Default::default() }
+		Self { cha: Cha::from(meta).with_kind(ck), url, link_to, icon: Default::default() }
 	}
 
 	#[inline]
-	pub fn from_dummy(url: &Url) -> Self { Self { url: url.to_owned(), ..Default::default() } }
+	pub fn from_dummy(url: Url, ft: Option<FileType>) -> Self {
+		Self { cha: ft.map_or_else(Cha::default, Cha::from), url: url.to_owned(), ..Default::default() }
+	}
 }
 
 impl File {
